@@ -12,7 +12,7 @@ from mycotools.lib.kontools import format_path, eprint, stdin2str
 def extract_mtdb_accs_exp(fa_dict, accs):
     return {acc: fa_dict[acc] for acc in accs}
 
-def extract_mtdb_accs(fa_dict, accs):
+def extract_mtdb_accs(fa_dict, accs, spacer = ''):
     """extract MTDB accessions from fa_dict using a list `accs`; can 
     extract coordinates of an accession if labeled 
     `acc[START:END] | acc[START-END]`. If start > end, extract the reverse
@@ -20,7 +20,7 @@ def extract_mtdb_accs(fa_dict, accs):
 
     out_fa = {}
     for acc in accs:
-        coords = acc[acc.find('['):acc.find(']')]
+        coords = acc[acc.find('[')+1:acc.find(']')]
         if coords: # if there are coordinates
             try: # try splitting by colon
                 start, end = [int(x) for x in coords.split(':')]
@@ -30,24 +30,35 @@ def extract_mtdb_accs(fa_dict, accs):
                 except ValueError: # invalid coordinates, try whole acc
                     out_fa[acc] = fa_dict[acc]
                     continue
-            acc_name = acc[:start]
+            acc_name = acc[:acc.find('[')]
             if start < end:
-                out_fa[acc] = {
-                    'sequence': fa_dict[acc_name]['sequence'][start:end+1],
-                    'description': fa_dict[acc_name]['description']
-                    }
+                try:
+                    out_fa[acc] = {
+                        'sequence': fa_dict[acc_name]['sequence'][start:end+1],
+                        'description': fa_dict[acc_name]['description']
+                        }
+                except KeyError:
+                    eprint(spacer + 'WARNING: invalid accession ' + acc_name, 
+                           flush = True)
             else:
-                out_fa[acc] = {
-                    'sequence': reverse_complement(
+                try:
+                    out_fa[acc] = {
+                        'sequence': reverse_complement(
                         fa_dict[acc_name]['sequence'][end-1:start+1]
                         ),
-                    'description': fa_dict[acc_name]['description']
-                    }
+                        'description': fa_dict[acc_name]['description']
+                        }
+                except KeyError:
+                    eprint(spacer + 'WARNING: invalid accession ' + acc_name,
+                           flush = True)
         else: # no coordinates
-            out_fa[acc] = fa_dict[acc] # extract the whole accession
+            try:
+                out_fa[acc] = fa_dict[acc] # extract the whole accession
+            except KeyError:
+                eprint(spacer + 'WARNING: invalid accession ' + acc_name,
+                       flush = True)
 
     return out_fa
-            
 
 def extractHeaders(fasta_file, accessions, ome = None):
     """searches headers for "[]", which indicate coordinate-based extraction.
@@ -90,7 +101,6 @@ def extractHeaders(fasta_file, accessions, ome = None):
                 out_fasta[header] = fasta[header]
 
     return out_fasta
-   
 
 def dbmain(db, accs, error = True, spacer = '\t\t\t', coord_check = True):
     """takes in mtdb, takes accessions ome by ome from accs;
@@ -117,7 +127,7 @@ def dbmain(db, accs, error = True, spacer = '\t\t\t', coord_check = True):
                 ome_fasta = fa2dict(db[ome]['faa'])
             except KeyError: # if there is a missing ome
                 if error:
-                    raise KeyError
+                    raise KeyError('invalid ome: ' + ome)
                 else:
                     eprint(spacer + ome + ' not in database', flush = True)
             fa_dict = {**fa_dict, **extract_mtdb_accs(ome_fasta, ome_accs)}
@@ -131,12 +141,10 @@ def dbmain(db, accs, error = True, spacer = '\t\t\t', coord_check = True):
                 else:
                     eprint(spacer + ome + ' not in database', flush = True)
             fa_dict = {**fa_dict, **extract_mtdb_accs_exp(ome_fasta, ome_accs)}
- 
 
     return fa_dict
 
-
-def famain( accs, fa, ome = None ):
+def famain(accs, fa, ome = None):
     """takes in accessions, fasta, and retrieves accessions"""
 
     fa_dict = {}
@@ -165,20 +173,28 @@ if __name__ == '__main__':
             with open(input_file, 'r') as raw:
                 accs = []
                 for line in raw:
-                    if not line.startswith('#'):
+                    if not line.startswith('#') and line.rstrip():
                         d = line.rstrip().split('\t')
                         accs.append([
                             d[args.column-1] + '[' + d[args.start-1] + '-' + d[args.end-1] + ']'
                             ])
         else:
             with open(input_file, 'r') as raw:
-                accs = [x.rstrip().split('\t')[args.column-1] for x in raw]
+                accs = [x.rstrip().split('\t')[args.column-1] \
+                        for x in raw if x.rstrip()]
     else: # assume we are using accessions
         if '-' == args.accession: # stdin
             data = stdin2str()
             accs = data.split()
         else:
-            accs = [args.accession]
+            if {'"', "'"}.intersection(set(args.accession)):
+                args.accession = args.accession.replace('"','').replace("'",'')
+            if ',' in args.accession:
+                accs = args.accession.split(',')
+            elif re.search(r'\s', args.accession):
+                accs = args.accession.split()
+            else:
+                accs = [args.accession]
        
     db_path = format_path(args.mtdb)
     if not args.fasta: # MTDB run
