@@ -30,7 +30,7 @@ def gff2svg(
     gff, svg_path, product_dict, colors,
     prod_comp = gff3Comps()['product'], width = 10,
     null = 'hypothetical protein', types = {'tRNA', 'mRNA', 'rRNA'},
-    max_size = 100, labels = True, gen_new_colors = True
+    max_size = 100, labels = True
     ):
     # needs to end with .svg
     if not svg_path.endswith('.svg'):
@@ -46,15 +46,10 @@ def gff2svg(
             if prod is not None:
                 product = prod[1].lower() # lower case for uniformity
                 product = product.replace('"', '')
-                if product in product_dict:
-                    pass
-                elif product == null or not product: # if the product is a null
+                if product == null or not product: # if the product is a null
                 # value it should be annotated as such
                     product = null
-                elif not gen_new_colors:
-                    product = null
                 elif product not in product_dict:
-                    print(product)
                     try: # try to use the next color
                         product_dict[product] = colors[count]
                         count += 1
@@ -106,11 +101,10 @@ def main(
     gff_list, svg_path, product_dict = {}, 
     width = 10, prod_comp = gff3Comps()['product'], 
     null = 'hypothetical protein', types = {'tRNA', 'mRNA', 'rRNA'},
-    labels = True, wheel = None, shuffle = False, gen_new_colors = True
+    labels = True, wheel = None, shuffle = False
     ):
 
-    product_dict = {str(k.lower()): v for k, v in product_dict.items()}
-    if not wheel and not product_dict:
+    if not wheel:
         if not set(product_dict.keys()).difference({null}): 
         # if no keys or null is the only product key
             products = compileProducts(gff_list, prod_comp, types = types)
@@ -121,10 +115,8 @@ def main(
         colors = getColors(1)
     elif wheel == 2:
         colors = getColors(17)
-    elif wheel == 3:
-        colors = getColors(28)
     else:
-        colors = None
+        colors = getColors(28)
 
     if shuffle:
         random.shuffle(colors)
@@ -135,7 +127,7 @@ def main(
     product_dict = gff2svg(
         gff_list, svg_path, product_dict, colors,
         prod_comp = prod_comp, width = width, null = null,
-        labels = labels, types = types, gen_new_colors = gen_new_colors
+        labels = labels, types = types
         )
 
     return product_dict
