@@ -100,8 +100,11 @@ def fa2dict(fasta_input, file_ = True):
             descrip = ''
 
         seq = val[1]
-        if seq[-1] == '\n' or seq[-1] == '\r':
-            seq = seq.rstrip()
+        if seq:
+            if seq[-1] == '\n' or seq[-1] == '\r':
+                seq = seq.rstrip()
+        else:
+            continue
 
         # prepares dictionaries for each gene with description, seq, rvcmpl_seq, and codons
         fasta_dict[gene] = {}
@@ -169,7 +172,7 @@ def dict2fa(fasta_dict, description = True):
             fasta_string += '>' + gene.rstrip() + '\n' + \
             fasta_dict[ gene ][ 'sequence' ].rstrip() + '\n'
 
-    return fasta_string.rstrip()
+    return fasta_string
 
 # need to turn these into classes and class functions
 def calc_gc(gene):
@@ -181,8 +184,6 @@ def calc_gc(gene):
 
     return(GC_con)
 
-
-
 # need to change into a class
 def gff2list(gff_info, path = True, error = True):
 
@@ -204,10 +205,10 @@ def gff2list(gff_info, path = True, error = True):
                 })
     except IndexError:
         raise IndexError(str(len(col_list)) + '/9 expected tab-' \
-                        + 'delimitted fields: ' + str(line))
+                        + 'delimitted fields: ' + str(col_list))
     except ValueError:
         raise ValueError(str(col_list[4:6]) + ' invalid integer ' \
-                        + 'conversion: ' + str(line))
+                        + 'conversion: ' + str(col_list))
             
     return gff_list_dict
 
@@ -242,6 +243,7 @@ def gff2Comps():
 
     comps = {}
     comps['id'] = r'name "([^"]+)"'
+    # this unfortunately includes "gene_name" from gtf naming
     comps['prot'] = r'proteinId ([^;]+)'
     comps['transcript'] = r'transcriptId ([^;]+)'
     comps['alias'] = r'alias "([^"]+)"'
@@ -253,7 +255,7 @@ def gff2Comps():
 def gtfComps():
 
     comps = {}
-    comps['id'] = r'gene_id "([^"]+)"'
+    comps['id'] = r'gene_id "?([^"]+)"?'
     comps['transcript'] = r'transcript_id "([^"]+)"'
     comps['alias'] = r'alias "([^"]+)"'
     comps['ver'] = 'gtf'
