@@ -16,7 +16,6 @@ def checksum(path, cmd = 'sha256', ref = ''):
         hash_res = subprocess.run([cmd + 'sum', path],
                                  stdout = subprocess.PIPE)
         hash_info = hash_res.stdout.decode('utf-8')
-        print(hash_info)
         hash_find = re.search(r'\w+', hash_info)
         hash_ = hash_find[0]
         if ref:
@@ -285,7 +284,7 @@ def findExecs( deps, exit = set(), verbose = True ):
     checks = []
     if type(deps) is str:
         deps = [deps]
-    for dep in deps:
+    for dep in sorted(deps):
         check = shutil.which( dep )
         vprint('{:<15}'.format(dep + ':', flush = True) + \
             str(check), v = verbose, e = True)
@@ -451,6 +450,36 @@ def sys_start( args, usage, min_len, dirs = [], files = [] ):
 
     return args
 
+
+def inject_args(args, injection_calls):
+    manual_cmds = []
+    for in_call in injection_calls:
+        if in_call in args:
+            prohibited = {';', '&', '&&', '\n', '\r'}
+            man_index = args.index(in_call)
+            for char in args[man_index + 1]:
+                if char == '"' or char == "'":
+                    quote_char = char
+    
+            manual_cmd, start = [], False
+            for i, v in args[man_index + 1:]:
+                if quote_char in v:
+                    if not start:
+                        start = True
+                        manual_cmd.append(v[v.find(quote_char):])
+                    else:
+                        manual_cmd.append(v[:v.find(quote_char)])
+                        break
+                else:
+                    manual_cmd.append(v)
+            for index in reversed(range(man_index, i + 1)):
+                del args[index]
+        else:
+            manual_cmd = []
+        manual_cmds.append(manual_cmd)
+    
+    return args, manual_cmds
+
  
 def intro( script_name, args_dict, credit='', log = False, stdout = True):
     '''
@@ -626,8 +655,72 @@ def file2list(file_, types = '', sep = None, col = None, compress = False):
     return data1_list
 
 
+class Subqueue():
+    """Run a subqueue of args; can run commands consecutively to avoid shell
+    limitations while maintaining shell injection security"""
+
+    def __init__(self, args, shell = False, verbose = False, injectable = False):
+        self.injectable = injectable
+        if verbose == 1 or verbose == True:
+            self.stdout = None
+            self.stderr = None
+        elif verbose == 2:
+            self.stdout = subprocess.DEVNULL
+            self.stderr = None
+        else:
+            self.stdout = subprocess.DEVNULL
+            self.stderr = subprocess.DEVNULL
+        if isinstance(args, list) \
+            or isinstance(args, tuple) \
+            or isinstance(args, set):
+            if isinstance(list(args)[0], str):
+                self.args = (tuple(args),)
+            elif isinstance(list(args)[0], list) \
+                or isinstance(list(args)[0], tuple) \
+                or isinstance(list(args)[0], set):
+                self.args = tuple([tuple(x) for x in args])
+            else:
+                raise TypeError('invalid argument subtype: ' \
+                              + str(type(list(args[0]))))
+                   
+        elif isinstance(args, str):
+            self.args = ((args,),)
+        else:
+            raise TypeError('invalid arguments type: ' + str(type(args)))
+        self.complete = False
+        self.shell = shell
+        self.status = [-1 for x in args]
+        self.exit = -1
+
+    def open(self):
+        for i, arg in enumerate(self.args):
+            if arg[-1] == '&&' and self.injectable:
+                failstop = True
+                arg = arg[:-1]
+            else:
+                failstop = False
+            self.status[i] = (subprocess.call(arg, shell = self.shell,
+                                               stdout = self.stdout,
+                                               stderr = self.stderr))
+            if failstop and self.status[i]:
+                break
+        self.exit = any(x for x in self.status)
+        self.complete = True
+        
+
+def run_subqueue(args, shell = False, verbose = False, injectable = False):
+ #   if args:
+    s = Subqueue(args, shell = shell, 
+                 verbose = verbose, 
+                 injectable = injectable)
+    s.open()
+    return args, s.exit
+#    return [], -420
+
+
 def multisub(args_lists, processes = 1, shell = False, 
-             verbose = False):
+             verbose = False, injectable = False):
+    import multiprocessing as mp
     '''
     Inputs: list of arguments, integer of processes, subprocess `shell` bool
     Outputs: launches and monitors subprocesses and returns list of exit 
@@ -645,7 +738,11 @@ def multisub(args_lists, processes = 1, shell = False,
         IF there are not arguments in args_lists, wait until all processes
         are complete before exiting the function.
     '''
-
+    with mp.Pool(processes = processes) as pool:
+        exit_pre = pool.starmap(run_subqueue, ((x, shell, verbose, injectable) \
+                                                for x in args_lists))
+    return [{'stdin': stdin, 'code': exit} for stdin, exit in exit_pre]
+"""
     if verbose:
         stdout, stderr = None, None
     else:
@@ -660,15 +757,17 @@ def multisub(args_lists, processes = 1, shell = False,
         while len(running) < processes and args_lists: # while not @ max
         # processes
             cmd = args_lists[0]
-            run_temp = subprocess.Popen(cmd , stdout = stdout, \
-                stderr = stderr, shell = shell) # run command
-            running.append([run_temp, cmd]) # add command to running
+#            run_temp = subprocess.Popen(cmd , stdout = stdout, \
+ #               stderr = stderr, shell = shell) # run command
+#            running.append([run_temp, cmd]) # add command to running
+            running.append([subqueue(cmd, shell = shell, verbose = verbose), 
+                            cmd])
+            mp.Process(target = running[-1].open)
             del args_lists[0] # delete from argument list to run
 
         if len(args_lists) > 0: # if there are remaining arguments
-            for index, handle in enumerate(running): # check each status
-                handle[0].poll()
-                returncode = handle[0].returncode
+            for q, cmd in running: # check each status
+                
                 if returncode is not None:
                     outputs.append({
                         'stdin': handle[1], 'code': returncode
@@ -688,3 +787,4 @@ def multisub(args_lists, processes = 1, shell = False,
                     del running[0]
 
     return outputs # [{stdin: '', code: int()}]
+"""
