@@ -31,6 +31,10 @@ def addMissing(gff_list, intron, comps, ome):
     rna_changes = {} # a dictionary for changing ambigious rna id names for
     # explicit RNA type references
     for entry in gff_list:
+        entry['attributes'] = \
+            entry['attributes'].replace('proteinId', 'protein_id')
+        entry['attributes'] = \
+            entry['attributes'].replace('transcriptId', 'transcript_id')
         addEntry = None
         id_ = re.search(comps['id'], entry['attributes'])[1]
         if 'gene' in entry['type']: # includes pseudogenes
@@ -71,7 +75,7 @@ def addMissing(gff_list, intron, comps, ome):
                     prot = search.groups()[1] # try the second
                 if re.search(comps['Alias'], entry['attributes'] ) is None:
                 # is there a mycotools alias or associated alias?
-                    if not entry['attributes'].endswith( ';' ):
+                    if not entry['attributes'].endswith(';'):
                         entry['attributes'] += ';'
                     alias = ome + '_' + prot # create an alias with the found
                     # protein
@@ -144,6 +148,21 @@ def addMissing(gff_list, intron, comps, ome):
                 entry['attributes'] += ';Parent=' + geneID
                 par = re.search(comps['par'], entry['attributes'])[1]
 
+            search = re.search(comps['prot'], entry['attributes'])
+            if search: # search for protein
+                prot = search.groups()[0] # try the first search
+                if not prot:
+                    prot = search.groups()[1] # try the second
+                if re.search(comps['Alias'], entry['attributes'] ) is None:
+                # is there a mycotools alias or associated alias?
+                    if not entry['attributes'].endswith(';'):
+                        entry['attributes'] += ';'
+                    alias = ome + '_' + prot # create an alias with the found
+                    # protein
+                    entry['attributes'] += 'Alias=' + ome + '_' + prot
+                    alt_alias[id_] = ome + '_' + prot
+
+
             rnas[id_] = par
             out_genes[par]['rna'].append(entry)
         elif entry['type'] == 'intron':
@@ -296,52 +315,41 @@ def compileGenes(cur_list, ome, pseudocount = 0, comps = gff3Comps(),
                 transcripts[par].append(id_)
 
     id_dict, pseudogenes = {}, set(pseudogenes)
-    if cur_seqids:
-        for i, entry in enumerate(cur_list):
-            if not entry['seqid'].startswith(ome + '_'):
-                entry['seqid'] = ome + '_' + entry['seqid']
-            if 'gene' in entry['type']:
-                id_ = re.search(comps['id'], entry['attributes'])[1]
-                id_dict[id_] = {}
-            elif entry['type'] == 'CDS':
-                try:
-                    par = re.search(comps['par'], entry['attributes'])[1]
-                except TypeError:
-                    continue
-                try:
-                    id_dict[rnas[par]][par] = re.search(comps['Alias'], entry['attributes'])[1]
-                except KeyError: # pseudogene or CDS parent is related to gene, not
-                # RNA
-                    id_dict[par][par] = re.search(comps['Alias'],
-                                                  entry['attributes'])[1]
-    else:
-        for i, entry in enumerate(cur_list):
-            if 'gene' in entry['type']:
-                id_ = re.search(comps['id'], entry['attributes'])[1]
-                id_dict[id_] = {}
-            elif entry['type'] == 'CDS':
-                try:
-                    par = re.search(comps['par'], entry['attributes'])[1]
-                except TypeError:
-                    continue
-                try:
-                    id_dict[rnas[par]][par] = re.search(comps['Alias'], entry['attributes'])[1]
-                except KeyError: # pseudogene or CDS parent is related to gene, not
-                # RNA
-                    id_dict[par][par] = re.search(comps['Alias'],
-                                                  entry['attributes'])[1]
+    for i, entry in enumerate(cur_list):
+        if 'gene' in entry['type']:
+            id_ = re.search(comps['id'], entry['attributes'])[1]
+            id_dict[id_] = {}
+        elif entry['type'] == 'CDS':
+            try:
+                par = re.search(comps['par'], entry['attributes'])[1]
+            except TypeError:
+                continue
+            try:
+                id_dict[rnas[par]][par] = re.search(comps['Alias'], entry['attributes'])[1]
+            except KeyError: # pseudogene or CDS parent is related to gene, not
+            # RNA
+                id_dict[par][par] = re.search(comps['Alias'],
+                                              entry['attributes'])[1]
 
     trna_count, rrna_count, ptrna_count, rna_count, etc_count = 1, 1, 1, 1, 1
     estranged = []
     for i, entry in enumerate(cur_list):
-        alias_tag, rna_check = ';Alias=', False
+        alias_tag, rna_check = 'Alias=', False
         if 'gene' in entry['type']:
             id_ = re.search(comps['id'], entry['attributes'])[1]
             if id_ in mrnas:
                 rna_check = True
                 if entry['type'] != 'pseudogene':
-                    for rna,alias in id_dict[id_].items():
+                    if id_dict[id_]:
+                        for rna,alias in id_dict[id_].items():
+                            alias_tag += alias + '|'
+                    else: # no CDS associated with mRNA
+                        alias = ome + '_etc' + str(etc_count)
                         alias_tag += alias + '|'
+                        etc_count += 1
+                        for rna in mrnas[id_]:
+                            id_dict[id_][rna] = alias
+                            
                 else:
                     for rna in mrnas[id_]:
                         alias = ome + '_pseudogene' + str(pseudocount)
@@ -383,7 +391,10 @@ def compileGenes(cur_list, ome, pseudocount = 0, comps = gff3Comps(),
                 alias_tag += alias + '|'
                 etc_count += 1
             alias_tag = alias_tag[:-1]
-            entry['attributes'] += alias_tag
+            if entry['attributes'].rstrip().endswith(';'):
+                entry['attributes'] += alias_tag
+            else:
+                entry['atrributes'] += ';' + alias_tag
         else:
             if 'Alias=' not in entry['attributes']:
                 if 'RNA' in entry['type']:
@@ -408,15 +419,25 @@ def compileGenes(cur_list, ome, pseudocount = 0, comps = gff3Comps(),
 #                       eprint(re.search(comps['id'], entry['attributes'])[1], entry['type'])
                         estranged.append((i, id_,))
                         continue
-                entry['attributes'] += alias_tag
+                if entry['attributes'].rstrip().endswith(';'):
+                    entry['attributes'] += alias_tag
+                else:
+                    entry['attributes'] += ';' + alias_tag
 
     for i, id_ in estranged:
         if not 'Alias=' in entry['attributes']:
             gene = rnas[id_]
             try: # acquire from the RNA retroactively
-                cur_list[i]['attributes'] += ';Alias=' + id_dict[gene][id_]
+                if cur_list[i]['attributes'].rstrip().endswith(';'):
+                    cur_list[i]['attributes'] += 'Alias=' + id_dict[gene][id_]
+                else:
+                    cur_list[i]['attributes'] += ';Alias=' + id_dict[gene][id_]
             except KeyError: # acquire from the gene
-                cur_list[i]['attributes'] += ';Alias=' + id_dict[gene][gene]
+                if cur_list[i]['attributes'].rstrip().endswith(';'):
+                    cur_list[i]['attributes'] += 'Alias=' + id_dict[gene][gene]
+                else:
+                    cur_list[i]['attributes'] += ';Alias=' \
+                                              +  id_dict[gene][gene]
                 id_dict[gene][id_] = id_dict[gene][gene]
                 # this assumes that for the case where CDSs' parents are genes,
                 # and mRNAs thus aren't related to the CDS alias directly, then
