@@ -7,7 +7,7 @@ import sys
 import argparse
 from mycotools.lib.biotools import gff2list, list2gff, gff2Comps, gff3Comps
 from mycotools.lib.kontools import format_path, eprint, vprint
-from mycotools.curAnnotation import addGenes, removeStartStop
+from mycotools.utils.gtf2gff3 import add_genes, remove_start_stop
 
 def gff2gff3(gff_list, ome, jgi_ome):
 
@@ -15,7 +15,12 @@ def gff2gff3(gff_list, ome, jgi_ome):
     for entry in gff_list:
         if entry['type'] == 'exon':
             name = re.search( comps2['id'], entry['attributes'] )[1]
+  #          try:
             transcript = re.search( comps2['transcript'], entry['attributes'] )[1]
+  
+  #except TypeError:
+ #               print(entry['attributes'], comps2['transcript'], flush = True)
+#                sys.exit()
             if name not in exon_dict:
                 exon_dict[name] = 0
             if name not in gene_dict:
@@ -97,19 +102,14 @@ def gff2gff3(gff_list, ome, jgi_ome):
     return out_list
 
 
-def main(gff_list, ome, jgi_ome, safe = True, verbose = True,
-         cur_seqids = False):
+def main(gff_list, ome, jgi_ome, safe = True, verbose = True):
 
-    gff_prep, failed, flagged = addGenes( gff_list, safe = safe )
+    gff_prep, failed, flagged = add_genes( gff_list, safe = safe )
     if failed:
         vprint( str(len(failed)) + '\tgenes failed', v = verbose , e = True, flush = True)
     if flagged:
         vprint( str(len(flagged)) + '\tgene coordinates from exons', v = verbose, e = True, flush = True)
     gff3 = gff2gff3(gff_prep, ome, jgi_ome)
-    if cur_seqids:
-        for entry in gff3:
-            if not entry['seqid'].startswith(ome + '_'):
-                entry['seqid'] = ome + '_' + entry['seqid']
 
     return gff3
 
