@@ -14,10 +14,9 @@ from mycotools.lib.biotools import gff2list, list2gff, fa2dict, dict2fa, \
     gtfComps, gff3Comps, gff2Comps
 from mycotools.lib.kontools import collect_files, eprint, format_path
 from mycotools.gff2seq import aamain as gff2proteome
-from mycotools.utils.curGFF3 import rename_and_organize
 
 
-def grabOutput(output_pref):
+def grabOutput( output_pref ):
     '''
     Inputs: orthofiller `output_path` for results
     Outputs: gff_dict and fasta_dict of results
@@ -27,21 +26,21 @@ def grabOutput(output_pref):
     '''
 
     output_path, pref = os.path.dirname(output_pref), os.path.basename(output_pref)
-    output_files = collect_files(output_path, '*')
+    output_files = collect_files( output_path, '*' )
     hits = [x for x in output_files if os.path.basename(x).startswith(pref)]
     proteome = [x for x in hits if x.endswith('.results.aa.fasta')]
-    gtf = [x for x in hits if x.endswith('.results.gtf')]
-    if len(gtf) != 1 or len(proteome) != 1:
-        if len(gtf) < 1 or len(proteome) < 1:
-            print('\nERROR: complete output files not detected' , flush = True)
+    gtf = [x for x in hits if x.endswith( '.results.gtf' )]
+    if len( gtf ) != 1 or len( proteome ) != 1:
+        if len( gtf ) < 1 or len( proteome ) < 1:
+            print( '\nERROR: complete output files not detected' , flush = True)
         else:
-            print('\nERROR: multiple eligible complete output detected' , flush = True)
-        sys.exit(3)
+            print( '\nERROR: multiple eligible complete output detected' , flush = True)
+        sys.exit( 3 )
 
-    return gff2list(gtf[0]), fa2dict(proteome[0])
+    return gff2list( gtf[0] ), fa2dict( proteome[0] )
 
 
-def intron2exon(gff, gene_comp = re.compile(r'gene_id \"(.*?)\"')):
+def intron2exon( gff, gene_comp = re.compile( r'gene_id \"(.*?)\"' ) ):
     '''
     Inputs: gff_dict
     Outputs: gff_dict with introns converted to exons
@@ -63,95 +62,92 @@ def intron2exon(gff, gene_comp = re.compile(r'gene_id \"(.*?)\"')):
     to the `new_gff`. Then add genes with new exons.
     '''
 
-    comps = gtfComps()
     gff1, gene_info = [], {}
     for entry in gff:
-        try:
-            gene = gene_comp.search(entry['attributes'])[1]
-        except TypeError:
-            if entry['type'] in {'transcript', 'gene'} and entry['source'] == 'AUGUSTUS':
-                continue
-            gene_comp = re.compile(r'name \"(.*?)\"')
-            gene = gene_comp.search(entry['attributes'])[1]
-            comps = gff2Comps()
         if int(entry['start']) > int(entry['end']):
             start, end = copy.deepcopy(entry['start']), copy.deepcopy(entry['end'])
             entry['start'], entry['end'] = end, start
+        gene = gene_comp.search( entry['attributes'] )[1]
         if gene not in gene_info:
-            gene_info[gene] = {
+            gene_info[ gene ] = { 
                 'intron': [], 
                 'start_codon': [], 
                 'stop_codon': [], 
                 'strand': str(entry['strand']), 
                 'raw': [] 
             }
-        if entry['type'] in gene_info[gene]:
-            gene_info[gene][entry['type']].append(
+        if entry[ 'type' ] in gene_info[ gene ]:
+            gene_info[ gene ][ entry['type'] ].append( 
                 [int(entry['start']), int(entry['end'])] 
             )
         gene_info[gene]['raw'].append(entry)
         gff1.append(entry)
 
-
-    intron_genes = {
+    intron_genes = { 
         gene: gene_info[gene] for gene in gene_info if gene_info[gene]['intron']
         }
     exon_coords = {}
     for gene in intron_genes:
 #        if intron_genes[gene]['intron']:
-        exon_coords[gene] = []
-        intron_genes[gene]['intron'].sort(key = lambda x: x[0])
+        exon_coords[ gene ] = []
+        intron_genes[gene]['intron'].sort( key = lambda x: x[0] )
     
         if intron_genes[gene]['strand'] == '+':
-            exon_coords[gene].append([intron_genes[gene]['start_codon'][0][0]])
+            exon_coords[gene].append( [intron_genes[gene]['start_codon'][0][0]] )
             for intron in intron_genes[gene]['intron']:
-                exon_coords[gene][-1].append(intron[0] - 1)
+                exon_coords[gene][-1].append( intron[0] - 1 )
                 exon_coords[gene].append([intron[1] + 1])
-            exon_coords[gene][-1].append(intron_genes[gene]['stop_codon'][0][1])
+            exon_coords[gene][-1].append( intron_genes[gene]['stop_codon'][0][1] )
 
         else:
-            exon_coords[gene].append([intron_genes[gene]['stop_codon'][0][0]])
+            exon_coords[gene].append( [intron_genes[gene]['stop_codon'][0][0]] )
             for intron in intron_genes[gene]['intron']:
-                exon_coords[gene][-1].append(intron[0] - 1)
+                exon_coords[gene][-1].append( intron[0] - 1 )
                 exon_coords[gene].append([intron[1] + 1])
-            exon_coords[gene][-1].append(intron_genes[gene]['start_codon'][0][1])
+            exon_coords[gene][-1].append( intron_genes[gene]['start_codon'][0][1] )
+#        elif intron_genes[gene]['start_codon']:
+ #           if intron_genes[gene]['strand'] == '+':
+  #              exon_coords[gene] = [[
+   #                 intron_genes[gene]['start_codon'][0][0], intron_genes[gene]['stop_codon'][0][1]
+    #                ]]
+     #       else:
+      #          exon_coords[gene] = [[
+       #             intron_genes[gene]['stop_codon'][0][0], intron_genes[gene]['start_codon'][0][1]
+        #            ]]
 
     gff2 = []
     for entry in gff1:
-        gene = gene_comp.search(entry['attributes'])[1]
+        gene = gene_comp.search( entry['attributes'] )[1]
         if gene not in exon_coords:
             gff2.append(entry)
     for gene in exon_coords:
-        add_data = [
+        add_data = [ 
             entry for entry in intron_genes[gene]['raw'] if entry['type'] != 'intron' 
         ]
         scaffold = list(add_data)[0]
         for exon in exon_coords[gene]:
-            new_entry = dict(scaffold)
+            new_entry = dict( scaffold )
             new_entry['type'] = 'exon'
-            new_entry['start'] = str(exon[0])
-            new_entry['end'] = str(exon[1])
+            new_entry['start'] = str( exon[0] )
+            new_entry['end'] = str( exon[1] )
             new_entry['score'] = '.'
             new_entry['phase'] = '.'
-            add_data.append(new_entry)
-        gff2.extend(add_data)
+            add_data.append( new_entry )
+        gff2.extend( add_data )
+
+    return gff2
 
 
-    return gff2, comps
-
-
-def curCDS(gff, gene_compile = re.compile(r'gene_id \"(.*?)\"')):
+def curCDS(gff):
 
     new_gff, info_dict = [], {}
+    gene_compile = re.compile(r'gene_id \"(.*?)\"')
     for entry in gff:
         if not gene_compile.search(entry['attributes']):
-            gene_compile = re.compile(r'ID=(.*?);')
-        try:
-            gene = gene_compile.search(entry['attributes'])[1]
-        except TypeError:
-            gene = gene_compile.search(entry['attributes'])[1]
+            gene_compile = re.compile( r'ID=(.*?);' )
+        gene = gene_compile.search(entry['attributes'])[1]
         if gene not in info_dict:
-            info_dict[gene] = {'start_codon': [], 'stop_codon': [], 'raw': []}
+            info_dict[gene] = { 'start_codon': [], 'stop_codon': [], 'raw': [] }
         if entry['type'] == 'gene':
 #            info_dict[gene]['start_codon'].extend(sorted([int(entry['end']) - 2, int(entry['end'])]))
             info_dict[gene]['start_codon'].extend(sorted([int(entry['end']), int(entry['start'])]))
@@ -189,7 +185,7 @@ def curCDS(gff, gene_compile = re.compile(r'gene_id \"(.*?)\"')):
     return new_gff
 
 
-def liberalRemoval(gene_dict_prep, contigs):
+def liberalRemoval( gene_dict_prep, contigs ):
 
     check_contigs, failed, gene_dict = {}, [], {}
     for i in contigs:
@@ -207,7 +203,7 @@ def liberalRemoval(gene_dict_prep, contigs):
 
     for gene in gene_dict_prep:
         if gene_dict_prep[gene]['start_codon'] and gene_dict_prep[gene]['stop_codon']:
-            gene_dict[gene] = gene_dict_prep[gene]
+            gene_dict[ gene ] = gene_dict_prep[gene]
         else:
 
             contig = gene_dict_prep[gene]['contig']
@@ -251,64 +247,57 @@ def conservativeRemoval(gene_dict_prep):
     for gene, temp in gene_dict_prep.items():
         rna_keys = []
         for typ in ['exon', 'cds', 'rna', 'start_codon', 'stop_codon']:
-            rna_keys.extend(set(temp[typ].keys()).difference({None}))
+            rna_keys.extend(list(temp[typ].keys()))
         rnas = list(set(rna_keys))
         try:
             for tran in rnas:
-                temp['exon'][tran].sort()
-                if not temp['start_codon'][tran]:
-                    if temp['strand'] == '+':
-                        temp['start_codon'][tran] = [
-                            temp['exon'][tran][0],
-                            temp['exon'][tran][0] + 2
-                            ]
-                    else:
-                        temp['start_codon'][tran] = [
-                            temp['exon'][tran][-1] - 2,
-                            temp['exon'][tran][-1]
-                            ]
-                if not temp['stop_codon'][tran]:
-                    if temp['strand'] == '+':
-                        temp['stop_codon'][tran] = [
-                            temp['exon'][tran][-1] - 2,
-                            temp['exon'][tran][-1]
-                            ]
-                    else:
-                        temp['stop_codon'][tran] = [
-                            temp['exon'][tran][0],
-                            temp['exon'][tran][0] + 3
-                            ]
-                flagged.append(gene)
+                if not temp['start_codon'][tran] \
+                    or not temp['stop_codon'][tran]:
+                    temp['exon'][tran].sort()
+                    if not temp['start_codon'][tran]:
+                        if temp['strand'] == '+':
+                            temp['start_codon'][tran] = [
+                                temp['exon'][tran][0],
+                                temp['exon'][tran][0] + 2
+                                ]
+                        else:
+                            temp['start_codon'][tran] = [
+                                temp['exon'][tran][-1] - 2,
+                                temp['exon'][tran][-1]
+                                ]
+                    if not temp['stop_codon'][tran]:
+                        if temp['strand'] == '+':
+                            temp['stop_codon'][tran] = [
+                                temp['exon'][tran][-1] - 2,
+                                temp['exon'][tran][-1]
+                                ]
+                        else:
+                            temp['stop_codon'][tran] = [
+                                temp['exon'][tran][0],
+                                temp['exon'][tran][0] + 3
+                                ]
+                    flagged.append(gene)
         except IndexError:
-            eprint(gene + ' cannot create gene coordinates' , flush = True)
+            eprint( gene + ' cannot create gene coordinates' , flush = True)
             continue
 
         gene_dict[gene] = temp
     
     return gene_dict, flagged, failed
         
-def fill_transcripts(gene_dict_prep):
-    # currently doesnt handle alternate splicing
-    for gene, typ_dict in gene_dict_prep.items():
-        if 'cds' in typ_dict and 'exon' in typ_dict:
-            if {None} == set(typ_dict['cds'].keys()):
-                if not None in typ_dict['exon']:
-                    if len(typ_dict['exon']) != 1:
-                        raise ValueError('cannot reconcile JGI gff2 alternate splicing')
-                    else:
-                        tran = list(typ_dict['exon'].keys())[0]
-                    typ_dict['cds'][tran] = typ_dict['cds'][None]
-                    del typ_dict['cds'][None]
-    return gene_dict_prep
 
-def add_genes(gtf, safe = True, 
-              comps = gtfComps(),
-              gene_prefix = 'gene_id'):
 
-    contigs = defaultdict(dict)
-    tran_compile = re.compile(comps['transcript'])
+def add_genes(gtf, safe = True):
+
+    comps, contigs = gtfComps(), defaultdict(dict)
     gene_compile = re.compile(comps['id'])
+    tran_compile = re.compile(comps['transcript'])
+#    if not gene_compile.search(gtf[0]['attributes']):
+ #       comps = gff2Comps()
+  #      gene_compile = re.compile(comps['id'])
+   #     tran_compile = re.compile(comps['transcript'])
     gene_dict_prep, gene_dict = {}, {}
+#    gene_compile = re.compile( r'gene_id "(.*?)";')
     for entry in gtf:
         gene = gene_compile.search(entry['attributes'])[1]
         try:
@@ -316,10 +305,8 @@ def add_genes(gtf, safe = True,
         except TypeError:
             tran = None
         contig = entry['seqid']
-        # prepare a dictionary that contains the hierarchy 
-        # for each gene
         if gene not in gene_dict_prep:
-            gene_dict_prep[gene] = {
+            gene_dict_prep[gene] = { 
                 'start_codon': defaultdict(list), 
                 'stop_codon': defaultdict(list), 
                 'exon': defaultdict(list),
@@ -331,28 +318,36 @@ def add_genes(gtf, safe = True,
         if entry['type'].lower() in {'start_codon', 'stop_codon'}:
             gene_dict_prep[gene][entry['type'].lower()][tran].extend(
                 sorted([int(entry['start']), int(entry['end'])])
-               )
+                )
         elif entry['type'].lower() in {'cds', 'exon'}:
             gene_dict_prep[gene][entry['type'].lower()][tran].extend(
                 sorted([int(entry['start']), int(entry['end'])])
-               )
+                )
         elif 'RNA' in entry['type']:
             gene_dict_prep[gene]['rna'][tran] = entry
-
-    gene_dict_prep = fill_transcripts(gene_dict_prep)
+   
     gene_dict, flagged, failed = conservativeRemoval(gene_dict_prep)
 
     check, insert_list = set(), []
     for index, entry in enumerate(gtf):
         gene = gene_compile.search(entry['attributes'])[1]
         if gene not in check and gene in gene_dict:
-            # make a new entry for this gene
             new_entry = dict(entry)
             new_entry['type'] = 'gene'
             new_entry['phase'], new_entry['score'] = '.', '.'
-            new_entry['attributes'] = f'{gene_prefix} "' + gene + '";'
-
-            # grab all start and stop coordinates for entries
+#            if comps['ver'] == 'gff2':
+ #               new_entry['attributes'] = 'name "' + gene + '";'
+#            else:
+            new_entry['attributes'] = 'gene_id "' + gene + '";'
+#            if gene_dict[gene]['start_codon'][0] > gene_dict[gene]['start_codon'][1]:
+ #               gene_dict[gene]['start_codon'] = [
+  #                  gene_dict[gene]['start_codon'][1], 
+   #                 gene_dict[gene]['start_codon'][0]
+    #                ]
+     #           gene_dict[gene]['stop_codon'] = [
+      #              gene_dict[gene]['stop_codon'][1], 
+       #             gene_dict[gene]['stop_codon'][1]
+        #            ]
             start_stop_coords = []
             for rna, coords in gene_dict[gene]['start_codon'].items():
                 start_stop_coords.extend(coords)
@@ -360,46 +355,46 @@ def add_genes(gtf, safe = True,
                 start_stop_coords.extend(coords)
             for rna, coords in gene_dict[gene]['exon'].items():
                 start_stop_coords.extend(coords)
- 
-            # use the minimum and maximum start stops to define the gene
             new_entry['start'] = min(start_stop_coords)
             new_entry['end'] = max(start_stop_coords)
-
-
-            # for each existing entry in the rnas of gene_dict, append a new
-            if gene_dict[gene]['rna']:
-                for rna, rna_entry in gene_dict[gene]['rna']:
-                    insert_list.extend([[index, rna_entry], [index, new_entry]])
-            # we must infer the coordinates from the exons
+#            if gene_dict[gene]['strand'] == '+':
+ #               new_entry['start'] = gene_dict[gene]['start_codon'][0]
+  #              new_entry['end'] = gene_dict[gene]['stop_codon'][1]
+   #         else:
+     #           new_entry['start'] = gene_dict[gene]['stop_codon'][0]
+      #          new_entry['end'] = gene_dict[gene]['start_codon'][1]
+            for rna, rna_entry in gene_dict_prep[gene]['rna']:
+#                new2 = copy.deepcopy(new_entry)
+ #               new2['type'] = gene_dict_prep[gene]['rna']
+                 insert_list.extend([[index, rna_entry], [index, new_entry]])
+#            elif not gene_dict_prep[gene]['cds']:
+ #               new2 = copy.deepcopy(new_entry)
+  #              new2['type'] = 'tRNA' # assume tRNA, but not valid to discredit rRNA
+   #             insert_list.extend([[index, new2], [index, new_entry]])
             else:
-                # for each transcript id in the exon information
                 for rna, coords in gene_dict[gene]['exon'].items():
-                    # if there aren't CDS then its an ambiguous RNA (tRNA/rRNA)
                     if not gene_dict[gene]['cds'][rna]:
-                        rna_type = 'RNA' # usually tRNA, but its not a safe assumption
-                        # from the data we are using
+                        rna_type = 'tRNA' # assumes tRNA if not coding, but
+                        # disregards rRNA, maybe should generalize to RNA
                     else:
                         rna_type = 'mRNA'
                     new2 = copy.deepcopy(new_entry)
                     coords.sort()
                     new2['type'] = rna_type
-                    # define the RNA from the minimum and maximum coordintes
                     new2['start'] = min(coords)
                     new2['end'] = max(coords)
-                    # give it a new entry
                     if new2['attributes'].endswith(';'):
                         new2['attributes'] += f' transcript_id "{rna}";'
                     else:
                         new2['attributes'] += f'; transcript_id "{rna}";'
-                    insert_list.append([index, new2])
-                # add one gene entry
+                    insert_list.extend([[index, new2]])
                 insert_list.append([index, new_entry])
             check.add(gene)
 
-    insert_list.sort(key = lambda x: x[0], reverse = True)
-
+    insert_list.sort( key = lambda x: x[0], reverse = True )
     for insert in insert_list:
-        gtf.insert(insert[0], insert[1])
+        gtf.insert( insert[0], insert[1] )
+
 
     return gtf, failed, flagged
 
@@ -408,9 +403,10 @@ def remove_start_stop(gtf):
     return [x for x in gtf if x['type'] not in {'start_codon', 'stop_codon'}]
 
 
-def curate(gff, prefix = None, failed = set(), comps = gtfComps()):
+def curate(gff, prefix = None, failed = set()):
 
     failed = set(failed)
+    comps = gtfComps()
     gene_comp = re.compile(comps['id'])
     tran_comp = re.compile(comps['transcript'])
 
@@ -421,15 +417,12 @@ def curate(gff, prefix = None, failed = set(), comps = gtfComps()):
     for line in gff:
         if line['type'] in {'exon', 'start_codon', 'stop_codon', 'CDS'} \
             or 'RNA' in line['type']:
-            try:
-                gene_id = gene_comp.search(line['attributes'])[1]
-            except TypeError:
-                gene_id = re.search(gtfComps()['id'], line['attributes'])[1]
+            gene_id = gene_comp.search(line['attributes'])[1]
             try:
                 tran_id = tran_comp.search(line['attributes'])[1]
             except TypeError:
                 print(line)
-                raise TypeError
+                sys.exit()
             if tran_id not in tran2gene:
                 tran2gene[tran_id] = gene_id
             elif not tran2gene[tran_id] == gene_id: # transcript points to
@@ -589,16 +582,16 @@ def sortGFF(unsorted_gff, idComp):
     return sortedGff
         
 
-def addExons(gff):
+def addExons( gff ):
 
     exon_check = {}
     for i in range(len(gff)):
         entry = gff[i]
         if entry['source'] == 'AUGUSTUS':
-            if entry['type'] in {'CDS', 'exon'}:
-                prot = re.search(r'ID=(.*?_\d+)', entry['attributes'])[1]
+            if entry['type'] in { 'CDS', 'exon' }:
+                prot = re.search( r'ID=(.*?_\d+)', entry['attributes'] )[1]
                 if prot not in exon_check:
-                    exon_check[prot] = [False, i, entry]
+                    exon_check[ prot ] = [False, i, entry]
                 if entry['type'] == 'exon':
                     exon_check[prot] = [True, i, None]
            
@@ -608,10 +601,11 @@ def addExons(gff):
             newEntry = copy.deepcopy(exon_check[prot][2])
             newEntry['attributes'] = newEntry['attributes'].replace('.cds;', '.exon1;')
             newEntry['type'] = 'exon'
-            gff.insert(exon_check[prot][1] + 1, newEntry)
+            gff.insert( exon_check[prot][1] + 1, newEntry )
 
     return gff
 
+
 def main(gff_path, prefix, fail = True):
 
     if isinstance(gff_path, str):
@@ -619,18 +613,18 @@ def main(gff_path, prefix, fail = True):
     elif isinstance(gff_path, list):
         gff = gff_path
 
-    exonGtf, comps = intron2exon(gff)
-    exonGtfCur = curCDS(exonGtf, re.compile(comps['id']))
-    exonGtfCurGenes, failed, flagged = add_genes(exonGtfCur, safe = fail, 
-                                                 comps = comps)
-
+    exonGtf = intron2exon(gff)
+    exonGtfCur = curCDS(exonGtf)
+    exonGtfCurGenes, failed, flagged = add_genes(exonGtfCur, safe = fail)
     preGff = remove_start_stop(exonGtfCurGenes)
-    unsortedGff, trans_str = curate(preGff, prefix, failed, comps) 
-#    unsortedGff = addExons(gffUncur)
+    gffUncur, trans_str = curate(preGff, prefix, failed) 
+    unsortedGff = addExons(gffUncur)
 
     if prefix:
-        out_gff = sortGFF(unsortedGff, re.compile(gff3Comps()['Alias']))
-        gff = rename_and_organize(out_gff)
+#        id_comp = re.compile(gff3Comps()['id'])
+ #       crude_sort = sorted(unsortedGff, key = lambda x: \
+  #          int(re.search(r'ID=' + prefix + '_(\d+)', x['attributes'])[1]))
+        gff = sortGFF(unsortedGff, re.compile(gff3Comps()['Alias']))
     else:
         gff = unsortedGff
 
@@ -640,8 +634,8 @@ def main(gff_path, prefix, fail = True):
 def sortMain(gff, prefix):
 
     id_comp = re.compile(gff3Comps()['id'])
-    crude_sort = sorted(gff, key = lambda x: \
-        int(re.search(r'ID=' + prefix + '_(\d+)', x['attributes'])[1]))
+    crude_sort = sorted( gff, key = lambda x: \
+        int( re.search(r'ID=' + prefix + '_(\d+)', x['attributes'])[1] ))
     gff = preSortGFF(crude_sort, id_comp)
 
     return gff
@@ -649,21 +643,21 @@ def sortMain(gff, prefix):
 
 if __name__ == '__main__':
 
-    parser = argparse.ArgumentParser(description = 'Curates Funannotate or ' + \
+    parser = argparse.ArgumentParser( description = 'Curates Funannotate or ' + \
         'post OrthoFiller output by naming accessions as <PREFIX>_####, where ' + \
         '#### is the is the index from ordered accessions. If you are planning' + \
-        ' on using OrthoFiller, you may want to wait to not mix accessions.')
-    parser.add_argument('-g', '--gff', required = True, help = '.gtf, .gff/.gff3')
-    parser.add_argument(
+        ' on using OrthoFiller, you may want to wait to not mix accessions.' )
+    parser.add_argument( '-g', '--gff', required = True, help = '.gtf, .gff/.gff3' )
+    parser.add_argument( 
         '-a', '--assembly', 
         help = 'Assembly fasta for proteome export. Requires -p' 
-       )
-    parser.add_argument('-p', '--prefix', help = 'Ome code for alias')
+        )
+    parser.add_argument('-p', '--prefix', help = 'Ome code for alias' )
     parser.add_argument('-s', '--sort', action = 'store_true',
         help = 'Only sort compatible gff3')
     parser.add_argument('-o', '--output', help = 'Output directory')
-#    parser.add_argument('--fail', default = True, action = 'store_false',
-#        help = 'Fail genes without start or stop codons.')
+#    parser.add_argument( '--fail', default = True, action = 'store_false',
+#        help = 'Fail genes without start or stop codons.' )
     args = parser.parse_args()
 
     if args.output:
@@ -677,38 +671,37 @@ if __name__ == '__main__':
 
     if args.sort:
         gff = sortMain(gff2list(format_path(args.gff)), args.prefix)
-        with open(output + '.gff3', 'w') as out:
-            out.write(list2gff(gff) + '\n')
+        with open( output + '.gff3', 'w' ) as out:
+            out.write( list2gff( gff ) + '\n' )
         sys.exit(0)
 #    elif not args.assembly:
  #       eprint('\nERROR: assembly (`-f`) required for curation\n', flush = True)
   #      sys.exit(2)
 
-    if args.prefix:
-        if '_' in args.prefix:
-            eprint('\nERROR: "_" not allowed in prefix\n', flush = True)
-            sys.exit(1)
+    if '_' in args.prefix:
+        eprint('\nERROR: "_" not allowed in prefix\n', flush = True)
+        sys.exit(1)
 
     gff, trans_str, failed, flagged = main(
         format_path(args.gff), args.prefix #, args.fail
         )
     if args.assembly and args.prefix:
         fna = fa2dict(format_path(args.assembly))
-        faa = gff2proteome(gff, fna)
-        with open(output + '.faa', 'w') as out:
-            out.write(dict2fa(faa))
+        faa = gff2proteome( gff, fna )
+        with open( output + '.faa', 'w' ) as out:
+            out.write( dict2fa( faa ) )
 
-    with open(output + '.gff3', 'w') as out:
-        out.write(list2gff(gff) + '\n')
-    with open(output + '.transitions', 'w') as out:
-        out.write(trans_str)
+    with open( output + '.gff3', 'w' ) as out:
+        out.write( list2gff( gff ) + '\n' )
+    with open( output + '.transitions', 'w' ) as out:
+        out.write( trans_str )
     if failed:
         print('\n' + str(len(failed)) + ' failures\n', flush = True)
-        with open(output + '.failed', 'w') as out:
+        with open( output + '.failed', 'w' ) as out:
             out.write('\n'.join(['\t'.join(x) for x in failed]))
     if flagged:
         print('\n' + str(len(flagged)) + ' flagged\n', flush = True)
-        with open(output + '.flagged', 'w') as out:
+        with open( output + '.flagged', 'w' ) as out:
             out.write('\n'.join(flagged))
 
     sys.exit(0)
